<?php

namespace App\Wrangler\Components;

use Illuminate\Http\Request;
use Medialight\Textstem\Helpers\MediaAsset;
use Medialight\Textstem\Models\Asset;
use Medialight\Textstem\Models\WranglerPage;
use Medialight\Textstem\Wrangler\ActiveComponent;

/**
 * Class Sample
 *
 * A short summary of what this component does.
 *
 * @extends ActiveComponent
 */
class ContentBlock extends ActiveComponent
{
    public static string $description = 'Create a content block (Image and media).';
    public static string $version = '1.0.0';

    public $config;

    public array $editSetup = [
        [
            'name' => 'template',
            'controltype' => 'select-template',
            'value' => 'default',
        ],
        [
            'name' => 'title',
            'controltype' => 'text',
            'value' => '',
            'label' => 'Title',
        ],
        [
            'name' => 'subtitle',
            'controltype' => 'text',
            'value' => '',
            'label' => 'Sub-Title',
        ],
        [
            'name' => 'content',
            'controltype' => 'richtext',
            'value' => '',
            'label' => 'Main  Content',
        ],
        [
            'name' => 'leadimg',
            'controltype' => 'image',
            'value' => '',
            'label' => 'Image',
        ],
        [
            'name' => 'images',
            'controltype' => 'image_collection',
            'value' => [],
            'casts' => 'array',
            'label' => 'Images',
        ],
        [
            'name' => 'outer_class',
            'controltype' => 'select',
            'value' => '',
            'options' => [
                '' => 'Default',
                'bg-blue-200' => 'Blue background',
                'bg-green-200' => 'Green background',
                'bg-gray-200' => 'Gray background',
                'bg-primary' => 'Primary background',
                'bg-secondary' => 'Secondary background',
            ],
            'label' => 'Background Style',
        ],
    ];

    public function render(Request $request, WranglerPage $wranglerPage)
    {
        $view = $this->getView();
        $data = $this->data();
        // asset
        $image = $data['leadimg'] ?? '';
        if ($image)
        {
            $data['asset'] =MediaAsset::loadForPath($image);
        }
        // imaghe collection
        $images = $data['images'] ?? [];
        if (! is_array($images)) {
            $images = json_decode($images, true);
        }
        $data['images'] = $images;
        $assets = Asset::whereIn('path', $images)->get();
        // sort the assets in the order they appear in the images array
        $data['assets'] = $assets->sortBy(function ($model) use ($images) {
            return array_search($model->path, $images);
        });
        // add any extra stuff the view needs to $data
        return view($view, $data)->render();
    }

    public function preview()
    {
        $view = $this->getPreview();
        $data = $this->data();
        return view($view, $data)->render();
    }
}
